% BBL GUI file: cl_bbllnd.m
% This supporting mfile runs the BBL program using the contour method.
%
% Usage: cl_bblgui
% Click on help buttons for tips.
%
% Version 1.2, 10Oct2005, C. A. Linder
% http://www.whoi.edu/science/PO/people/clinder/software_bbl.html
%

regsigma=[min(min(RegSigmatheta))+0.01:deltasigma:max(max(RegSigmatheta))-0.01];
numsigmas=length(regsigma);

disp('** PLOT 2 ** Sigma-theta contours...  acquiring contour data.');
f2=figure;
for loop=1:numsigmas
  eval(sprintf('[c%d,h%d]=contour(origRegX,origRegY,RegSigmatheta,[regsigma(%d) regsigma(%d)],''k'');',loop,loop,loop,loop));
  hold on;
  % This line is critical - the program is acquiring the x-y contours.
  eval(sprintf('c%d=c%d'';',loop,loop));
end;

numgood=0;
disp('Cleaning contour lines...');
for loop=1:numsigmas % Begin cleaning these contour lines
  % The first line indicates how long the segment is (rows).
  eval(sprintf('linedata=c%d;',loop));
  numsegrows=linedata(1,2);
  seg1=linedata(2:numsegrows+1,:);
  numsegs=1;
 
  while length(linedata) > linedata(1,2)+1  % Then we know there are multiples - loop through & grab em.
      numsegs=numsegs+1;
      linedata=linedata(numsegrows+2:end,:);
      numsegrows=linedata(1,2);
      eval(sprintf('seg%d=linedata(2:numsegrows+1,:);',numsegs));
  end;

  for subloop=1:numsegs
      eval(sprintf('maxseg=seg%d;',subloop));
      % Now we need to run some tests to see if this segment is good or
      % not.  We want to eliminate
      % a) Segments starting AND ending at surface.
      % b) Closed loops
      % c) Segments starting AND ending on bottom
      % d) Segments starting from LHS of page
      % e) Segments starting from BOTTOM of page
      goodseg=0; % Assume the worst!
      if (maxseg(1,2) > (5+min(origRegY(:,1)))) & (maxseg(1,2) ~= maxseg(end,2)) % First eliminate any contours beginning within 5m of BOTTOM OF PLOT and closed contours
          % Let's try a new if statement... we want only those contours which are close to the bottom... so, let's find out
          % what the interpolated bottom depth is for a given x-loc of contour, and then if it's within 5m of that number, include it.
          realorigboty=interp1(avgsec(:,1),avgsec(:,2),maxseg(1,1));
          realtermboty=interp1(avgsec(:,1),avgsec(:,2),maxseg(end,1));
          % Now, check that one end is > 10m from bottom
          origdiff=abs(realorigboty - maxseg(1,2));  % This is the difference between the start of the segment and the bottom
          termdiff=abs(realtermboty - maxseg(end,2));  % This is the difference between the end of the segment and the bottom
          if origdiff < 10
              if termdiff < 10
                  % BAD - it originates and terminates on the bottom!
                  goodseg=0;
              else % This is the best case - segment originates within 10m, and terminates > 10m
                  goodseg=1;    
              end;
          elseif termdiff < 10
              maxseg=flipud(maxseg);
              goodseg=1;
          else
              % BAD - both origination and terimination > 10m from bottom
              goodseg=0;
          end;
          % Now we know what the orientation is, let's just kick out those
          % that terminate on the LHS or BOTTOM, we don't want those.
          if maxseg(end,2) < (5+min(origRegY(:,1))) % Terminating on bottom
              goodseg=0;
          end;
          if maxseg(end,1) < (5+min(origRegX(1,:))) % Terminating on left wall
              goodseg=0;
          end;
          if(goodseg)
              numgood=numgood+1;
              eval(sprintf('cnew%d=maxseg;',numgood));      
              eval(sprintf('plot(cnew%d(:,1),cnew%d(:,2),''mo-'',''markersize'',1,''linewidth'',1);',numgood,numgood));
              eval(sprintf('plot(cnew%d(1,1),cnew%d(1,2),''g.'',''markersize'',10);',numgood,numgood));
              eval(sprintf('plot(cnew%d(end,1),cnew%d(end,2),''r.'',''markersize'',10);',numgood,numgood));
          end;
      end;

      
  end;
end; % cleaning

xlabel('Distance from first cast (km)');
ylabel('Depth (m)');
yt=get(gca,'ytick');
set(gca,'ytick',yt);
set(gca,'yticklabel',abs(yt));
hold on; plot(avgsec(:,1),avgsec(:,2),'k');
title(['Sigma-theta contours that program is going to integrate along.  Green/red dots indicate start/end points.']);
ylim([MinY MaxY+2]);
suptitle(inputfile);


if numgood==0
  disp('No good contours found - aborting!');
else

% accum T/salinity/Spice along isopycnals...

disp('Calculating accumulated theta/salinity/spice change along each contour...');
for loop=1:numgood
   switch parameter
   case 1
      eval(sprintf('t%d=interp2(origRegX,origRegY,RegTheta,cnew%d(:,1),cnew%d(:,2));',loop,loop,loop));
   case 2
      eval(sprintf('t%d=interp2(origRegX,origRegY,RegSalinity,cnew%d(:,1),cnew%d(:,2));',loop,loop,loop));
   case 3
      eval(sprintf('t%d=interp2(origRegX,origRegY,RegSpice,cnew%d(:,1),cnew%d(:,2));',loop,loop,loop));
   end;
   
  eval(sprintf('inonan=find(isnan(t%d)==0);',loop));
  eval(sprintf('t%d=t%d(inonan);',loop,loop));
  eval(sprintf('temp=t%d;',loop));
  if isempty(temp)
    eval(sprintf('x%d=NaN;',loop));
    eval(sprintf('z%d=NaN;',loop));
    eval(sprintf('accumt%d=NaN;',loop));
  else
    eval(sprintf('x%d=cnew%d(inonan,1);',loop,loop));
    eval(sprintf('z%d=cnew%d(inonan,2);',loop,loop));
    eval(sprintf('accumt%d=cumsum(abs(gradient(t%d-t%d(1))));',loop,loop,loop));
  end;
end;

disp('** PLOT 3 ** Plotting raw (scatterplot) accumulated theta/salinity/spice change...');
f4=figure;
for loop=1:numgood
  eval(sprintf('scatter(x%d,z%d,20,accumt%d,''filled'');',loop,loop,loop));
  if isempty(accumthetacaxis)==0
    caxis(accumthetacaxis);
  end;
  hold on;
end;
axis([min(min(origRegX)) max(max(origRegX)) min(min(origRegY)) max(max(origRegY))]); 
grid on;
plot(avgsec(:,1),avgsec(:,2),'k');
xlabel('Distance from first cast (km)');
ylabel('Depth (m)');
yt=get(gca,'ytick');
set(gca,'ytick',yt);
set(gca,'yticklabel',abs(yt));
hold on; plot(avgsec(:,1),avgsec(:,2),'k');
switch parameter
case 1
   title(['Raw (scatterplot) accumulated theta change (',setstr(176),'C)']);
case 2
   title(['Raw (scatterplot) accumulated salinity change']);
case 3
   title(['Raw (scatterplot) accumulated spiciness change (kg/m^3)']);
end;
suptitle(inputfile);


disp('Forcing raw scatterplot onto a regular grid for plotting...');
xyzfile=[];
for loop=1:numgood
   eval(sprintf('xyzfile=[xyzfile; x%d z%d accumt%d];',loop,loop,loop));
end;
xbounds=min(min(origRegX)):abs((origRegX(1,2)-origRegX(1,1))):max(max(origRegX));
ybounds=fliplr(min(min(origRegY)):abs((origRegY(2,1)-origRegY(1,1))):max(max(origRegY)));

blankfile=[avgsec; avgsec(length(avgsec),1) min(avgsec(:,2))-10; min(xbounds) min(avgsec(:,2))-10; avgsec(1,:)];
disp('Saving blanking file...');
save blankfile.temp blankfile -ascii

disp('  Computing regular grids using Matlab ppzgrid');
eval(sprintf('[Z,grd]=ppzinit(xyzfile,''-R%d/%d/%d/%d -I%d/%d -Mblankfile.temp'');',min(xbounds),max(xbounds),min(ybounds),max(ybounds),abs(xbounds(2)-xbounds(1)),abs(ybounds(2)-ybounds(1))));
if smoothing > 0 
    eval(sprintf('[ppz,grdout]=ppsmooth(Z,grd,''-S%d'');',smoothing));
else
    ppz=Z;
end;
acctheta=flipud(ppz);
[Xnew,Ynew]=meshgrid([min(xbounds):abs(xbounds(2)-xbounds(1)):max(xbounds)],[max(ybounds):-abs(ybounds(2)-ybounds(1)):min(ybounds)]);

disp('** PLOT 4 ** Accumulated theta/salinity/spiciness change in regular z space...');
f5=figure; subplot(211);
[c,h]=contourf(origRegX,origRegY,RegTheta,[floor(min(min(RegTheta))):1:ceil(max(max(RegTheta)))]);
for loop=1:length(h); set(h(loop),'linestyle','none'); end;
hold on;
[cbw,hbw]=contour(origRegX,origRegY,RegTheta,[0:1:40],'k');
clabel(cbw,hbw,'fontweight','bold');
[cm,hm]=contour(origRegX,origRegY,RegSigmatheta,sigmathetacontours,'m');
set(hm,'linewidth',2);
clabel(cm,hm,'color','m','fontweight','bold');
fill(blankfile(:,1),blankfile(:,2),'w');
colormap(jet);
%cl_thetacolorbarf(c,h);
axis([MinX MaxX MinY MaxY]);
title(['Theta (',setstr(176),'C)']);
ylabel('Depth (m)');
yt=get(gca,'ytick');
set(gca,'ytick',yt);
set(gca,'yticklabel',abs(yt));
text((range-(0.01*max(range))),[ones(size(range))*(0.02*abs(min(origRegY(:,1))))],'+');

subplot(212);
%[C,H,CF]=contourf(origRegX,origRegY,acctheta,accumthetacontours); hold on; %Matlab v65

[C,H]=contourf('v6',origRegX,origRegY,acctheta,accumthetacontours); hold on; %Matlab v7
caxis([min(accumthetacontours) max(accumthetacontours)]);

for junkloop=1:length(H) set(H(junkloop),'linestyle','none'); end;
%load bblcolormap;
%colormap(bbl22colormap);
colormap(jet);
%cl_bblcolorbarf(C,H);
if accumthetacontours(1)==0
    [c,h]=contour(origRegX,origRegY,acctheta,accumthetacontours(2:end),'k');
else
    [c,h]=contour(origRegX,origRegY,acctheta,accumthetacontours,'k');
end;
clabel(c,h,'fontweight','bold');
hold on;
[cm,hm]=contour(origRegX,origRegY,RegSigmatheta,sigmathetacontours,'m');
set(hm,'linewidth',2);
clabel(cm,hm,'color','m','fontweight','bold'); 

hold on; fill(blankfile(:,1),blankfile(:,2),'w');
axis([MinX MaxX MinY MaxY]);
switch parameter
case 1
   title(['Accumulated theta change (',setstr(176),'C)']);
case 2
   title(['Accumulated salinity change - deltasigmatheta = ',num2str(deltasigma)]);
case 3
   title(['Accumulated spiciness change (kg/m^3) - deltasigmatheta = ',num2str(deltasigma)]);
end;
xlabel(['Distance from first cast (km)']);
ylabel(['Depth (m)']);
yt=get(gca,'ytick');
set(gca,'ytick',yt);
set(gca,'yticklabel',abs(yt));
text((range-(0.01*max(range))),[ones(size(range))*(0.02*abs(min(origRegY(:,1))))],'+');

% Save out feature

if(saveout)
   disp('Appending output to profile* files and saving outfile.mat...');
   for loop=1:numcasts
      eval(sprintf('profile%d=[profile%d interp2(origRegX,origRegY,acctheta,range(%d),profile%d(:,1))];',loop,loop,loop,loop));
   end;
   save outfile range profile* posits;
end;

end; % if numgood=0

% ********** PROGRAM END **********
disp('BBL analysis completed!');
disp(' ');