% BBL GUI file: cl_bblplt.m
% This supporting mfile will load and grid the data and call the required compute/plot routine.
%
% Usage: cl_bblgui
% Click on help buttons for tips.
%
% Version 1.2, 10Oct2005, C. A. Linder
% http://www.whoi.edu/science/PO/people/clinder/software_bbl.html
%

% Load data and calc range and derivedxyzdata with bblqry.

query=0;
cl_bblqry;
if exist([inputfile '.mat'])==0
else  % Continue...
blankfile=[avgsec; avgsec(length(avgsec),1) min(avgsec(:,2))-10; min(xbounds) min(avgsec(:,2))-10; avgsec(1,:)];
disp('Saving blanking file...');
save blankfile.temp blankfile -ascii

disp('  Computing regular grids using Matlab ppzgrid');
mymat=[derivedxyzdata(:,1) derivedxyzdata(:,2) derivedxyzdata(:,5)];   
eval(sprintf('[Z,grd]=ppzinit(mymat,''-R%d/%d/%d/%d -I%d/%d -Mblankfile.temp'');',MinX,MaxX,MinY,MaxY,DelX,DelY));
if smoothing > 0 
    eval(sprintf('[ppz,grdout]=ppsmooth(Z,grd,''-S%d'');',smoothing));
else
    ppz=Z;
end;
RegSigmatheta=flipud(ppz);
mymat=[derivedxyzdata(:,1) derivedxyzdata(:,2) derivedxyzdata(:,3)];   
eval(sprintf('[Z,grd]=ppzinit(mymat,''-R%d/%d/%d/%d -I%d/%d -Mblankfile.temp'');',MinX,MaxX,MinY,MaxY,DelX,DelY));
if smoothing > 0 
    eval(sprintf('[ppz,grdout]=ppsmooth(Z,grd,''-S%d'');',smoothing));
else
    ppz=Z;
end;
RegTheta=flipud(ppz);
mymat=[derivedxyzdata(:,1) derivedxyzdata(:,2) derivedxyzdata(:,4)];   
eval(sprintf('[Z,grd]=ppzinit(mymat,''-R%d/%d/%d/%d -I%d/%d -Mblankfile.temp'');',MinX,MaxX,MinY,MaxY,DelX,DelY));
if smoothing > 0 
    eval(sprintf('[ppz,grdout]=ppsmooth(Z,grd,''-S%d'');',smoothing));
else
    ppz=Z;
end;
RegSalinity=flipud(ppz);
[origRegX,origRegY]=meshgrid([MinX:DelX:MaxX],[MaxY:-DelY:MinY]);

disp('** PLOT 1 ** Theta, salinity and sigma-theta...');
f1=figure;
subplot(311);
[c,h]=contourf(origRegX,origRegY,RegTheta,32);
for loop=1:length(h); set(h(loop),'linestyle','none'); end;
hold on;
[cbw,hbw]=contour(origRegX,origRegY,RegTheta,[0:1:40],'k');
clabel(cbw,hbw,'fontweight','bold');
[cm,hm]=contour(origRegX,origRegY,RegSigmatheta,sigmathetacontours,'m');
set(hm,'linewidth',2);
clabel(cm,hm,'color','m','fontweight','bold');
fill(blankfile(:,1),blankfile(:,2),'w');
%colorbar('vertical');
axis([MinX MaxX MinY MaxY]);
title(['Theta (',setstr(176),'C)']);
ylabel('Depth (m)');
yt=get(gca,'ytick');
set(gca,'ytick',yt);
set(gca,'yticklabel',abs(yt));
text((range-(0.01*max(range))),[ones(size(range))*(0.02*abs(min(origRegY(:,1))))],'+');

subplot(312);
[c,h]=contourf(origRegX,origRegY,RegSalinity,32);
for loop=1:length(h); set(h(loop),'linestyle','none'); end;
hold on;
[cbw,hbw]=contour(origRegX,origRegY,RegSalinity,[0:0.5:40],'k');
clabel(cbw,hbw,'fontweight','bold');
[cm,hm]=contour(origRegX,origRegY,RegSigmatheta,sigmathetacontours,'m');
set(hm,'linewidth',2);
clabel(cm,hm,'color','m','fontweight','bold');
fill(blankfile(:,1),blankfile(:,2),'w');
%colorbar;
axis([MinX MaxX MinY MaxY]);
title('Salinity')
ylabel('Depth (m)');
yt=get(gca,'ytick');
set(gca,'ytick',yt);
set(gca,'yticklabel',abs(yt));
text((range-(0.01*max(range))),[ones(size(range))*(0.02*abs(min(origRegY(:,1))))],'+');

subplot(313);
[c,h]=contourf(origRegX,origRegY,RegSigmatheta,32);
for loop=1:length(h); set(h(loop),'linestyle','none'); end;
hold on;
[cm,hm]=contour(origRegX,origRegY,RegSigmatheta,sigmathetacontours,'k');
set(hm,'linewidth',2);
clabel(cm,hm,'fontweight','bold');
fill(blankfile(:,1),blankfile(:,2),'w');
%colorbar;
axis([MinX MaxX MinY MaxY]);
title('Sigma-theta (kg/m^3)')
xlabel('Distance from first cast (km)');
ylabel('Depth (m)');
yt=get(gca,'ytick');
set(gca,'ytick',yt);
set(gca,'yticklabel',abs(yt));
suptitle(inputfile);
text((range-(0.01*max(range))),[ones(size(range))*(0.02*abs(min(origRegY(:,1))))],'+');

set(gcf,'paperunits','inches');
set(gcf,'paperposition',[0.25 0.25 8 10.5]);

if holdplots
  disp('          ****Hit return to continue****');
  pause;
end;

if parameter==3
   RegSpice=spice(RegTheta,RegSalinity);
end;

% At this point we have regularly gridded and plotted the data.  Now time to perform calcs.

disp('Running the BBL cruncher.');
cl_bbllnd;

end;