% BBL GUI file: cl_bblqry.m
% This supporting mfile will load and query the data. It helps the user set the gridding ranges.
%
% Usage: cl_bblgui
% Click on help buttons for tips.
%
% Version 1.2, 10Oct2005, C. A. Linder
% http://www.whoi.edu/science/PO/people/clinder/software_bbl.html
%

if exist([inputfile '.mat'])==0
   msgbox('Warning!  File not found - check directory.','Error!');    
else  % Continue...
   disp('Loading data.');
   clear rawprofile*;
   clear posits;
   eval(sprintf('load(''%s'');',inputfile));
   lats=[posits(:,2)+posits(:,3)/60];
   lons=[posits(:,4)+posits(:,5)/60];
   [range,angle]=sw_dist(lats,lons,'km');
   range=[0 cumsum(range)'];
   avgsec=[range' -1*abs(posits(:,6))];
   [r,c]=size(posits);
   numcasts=r;

   %
   % Load raw data, compute derived and interpolated data 
   %

   disp('Computing derived variables.');
   derivedxyzdata=[];
   for loop=1:numcasts
     eval(sprintf('rawdata=rawprofile%d;',loop));
     [r,c]=size(rawdata);
     % Compute depth, theta, and sigma-theta from P, T, and S
     depth=-1*sw_dpth(abs(rawdata(:,1)),lats(loop));
     salinity=rawdata(:,3);
     theta=sw_ptmp(salinity,rawdata(:,2),abs(rawdata(:,1)),0);
%     sigmatheta=sw_dens0(salinity,theta)-1000;
     sigmatheta=sw_pden(salinity,rawdata(:,2),abs(rawdata(:,1)),0)-1000;


     % Stabilize sigmatheta
%    for stloop=2:r
%	if sigmatheta(stloop)<sigmatheta(stloop-1)
%		sigmatheta(stloop)=sigmatheta(stloop-1)+0.001;
%	end;
%     end;
     eval(sprintf('profile%d=[-1*abs(depth) theta salinity sigmatheta];',loop));
     derivedxyzdata=[derivedxyzdata; range(loop)*ones(length(depth),1) -1*abs(depth) theta salinity sigmatheta spice(theta,salinity)];    
   end;



   if(query)
     qt=cell(1,1);
     qt{1}='Data parameters';
     qt{2}=' ';
     qt{3}=['Minimum range (km): ',num2str(min(derivedxyzdata(:,1)))];
     qt{4}=['Maximum range (km): ',num2str(max(derivedxyzdata(:,1)))];
     qt{5}=['Maximum depth (m): ',num2str(min(derivedxyzdata(:,2)))];
     qt{6}=['Minimum depth (m): ',num2str(max(derivedxyzdata(:,2)))];
     qt{7}=['Minimum sigma-theta: ',num2str(min(derivedxyzdata(:,5)))];
     qt{8}=['Maximum sigma-theta: ',num2str(max(derivedxyzdata(:,5)))];
     msgbox(qt,'Query results');
   end; % Query actions

end;